@@ -1,7 +1,7 @@
 /*
 Global includes.
 
-Copyright 2017-2020 Alexander Kulak.
+Copyright 2017-2021 Alexander Kulak.
 This file is part of alttab program.
 
 alttab is free software: you can redistribute it and/or modify
@@ -36,6 +36,7 @@ along with alttab.  If not, see <http://www.gnu.org/licenses/>.
 #define DEFTILEH    128
 #define DEFICONW    32
 #define DEFICONH    32
+#define DEFBORDERW  0
 #define DEFTHEME    "hicolor"
 #define FRAME_W     8
 //#define DEFFONT   "xft:DejaVu Sans Condensed-10"
@@ -44,10 +45,12 @@ along with alttab.  If not, see <http://www.gnu.org/licenses/>.
 #define COLBG       0
 #define COLFG       1
 #define COLFRAME    2
-#define NCOLORS     3
+#define COLBORDER   3
+#define NCOLORS     4
 #define DEFCOLBG    "black"
 #define DEFCOLFG    "grey"
 #define DEFCOLFRAME "#a0abab"
+#define DEFCOLBORDER "black"
 
 #define XDEPTH      24          // TODO: get rid of this
 
@@ -150,8 +153,12 @@ typedef struct {
 #define SCR_DEFAULT    SCR_ALL
     int option_screen;
     char *option_font;
+#define VERTICAL_DEFAULT false
+    bool option_vertical;
     int option_tileW, option_tileH;
     int option_iconW, option_iconH;
+#define BORDER_MIN      0
+    int option_borderW;
 #define VP_FOCUS        0
 #define VP_POINTER      1
 #define VP_TOTAL        2
@@ -243,5 +250,6 @@ bool randrGetViewport(quad * res, bool * multihead);
 /* autil */
 void die(const char *format, ...);
 void msg(int lvl, const char *format, ...);
+void sighandler(int signum);
 
 #endif
